@@ -2,7 +2,7 @@
  * audio.h -- All the audio related stuff
  *
  * Copyright (C) 2007-2009 Igalia, S.L.
- * Authors: Alberto Garcia <agarcia@igalia.com>
+ * Authors: Alberto Garcia <berto@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3
  * See the README file for more details.
@@ -15,8 +15,6 @@
 
 #define GST_DECODER_ENVVAR "VAGALUME_GST_DECODER"
 #define GST_SINK_ENVVAR "VAGALUME_GST_SINK"
-#define GST_CONVERT_ENVVAR "VAGALUME_GST_CONVERT"
-#define GST_MIXER_ENVVAR "VAGALUME_GST_MIXER"
 
 gboolean
 lastfm_audio_init                       (void);
@@ -47,12 +45,6 @@ lastfm_audio_clear                      (void);
 const char *
 lastfm_audio_default_decoder_name       (void);
 
-const char *
-lastfm_audio_default_convert_name       (void);
-
-const char *
-lastfm_audio_default_mixer_name         (void);
-
 const char *
 lastfm_audio_default_sink_name          (void);
 
