@@ -1,8 +1,8 @@
 /*
  * main.c -- Main file, basic initialization
  *
- * Copyright (C) 2007-2010 Igalia, S.L.
- * Authors: Alberto Garcia <agarcia@igalia.com>
+ * Copyright (C) 2007-2011, 2013 Igalia, S.L.
+ * Authors: Alberto Garcia <berto@igalia.com>
  *
  * This file is part of Vagalume.
  *
@@ -46,7 +46,9 @@ main                                    (int    argc,
         char *radio = NULL;
 
         signal(SIGPIPE, SIG_IGN);
+#if !GLIB_CHECK_VERSION(2,32,0)
         g_thread_init (NULL);
+#endif
         gdk_threads_init ();
 #ifdef HAVE_DBUS_SUPPORT
         dbus_g_thread_init ();
@@ -63,42 +65,31 @@ main                                    (int    argc,
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
 
-        if (g_getenv ("VAGALUME_DEBUG") == NULL) {
+        if (g_getenv ("VAGALUME_DEBUG") == NULL &&
+            g_getenv ("G_MESSAGES_DEBUG") == NULL) {
                 g_log_set_handler (NULL, G_LOG_LEVEL_DEBUG,
                                    (GLogFunc) gtk_true, NULL);
         }
 
 #if defined(HAVE_GETOPT) && !defined(MAEMO)
         int opt;
-        while ((opt = getopt(argc, argv, "c:d:m:s:h")) != -1) {
+        while ((opt = getopt(argc, argv, "d:s:h")) != -1) {
                 switch (opt) {
-                case 'c':
-                        g_setenv(GST_CONVERT_ENVVAR, optarg, TRUE);
-                        break;
                 case 'd':
                         g_setenv(GST_DECODER_ENVVAR, optarg, TRUE);
                         break;
-                case 'm':
-                        g_setenv(GST_MIXER_ENVVAR, optarg, TRUE);
-                        break;
                 case 's':
                         g_setenv(GST_SINK_ENVVAR, optarg, TRUE);
                         break;
                 default:
-                        g_print(_("Usage:\n  %s [-c converter] [-d decoder] "
-                                  "[-m mixer] [-s sink] [lastfm radio url]\n\n"
-                                  "  converter: GStreamer converter "
-                                  "(default: '%s', 'none' to disable)\n"
+                        g_print(_("Usage:\n  %s [-d decoder] "
+                                  "[-s sink] [lastfm radio url]\n\n"
                                   "  decoder:   GStreamer decoder "
                                   "(default: '%s')\n"
-                                  "  mixer:     GStreamer mixer "
-                                  "(default: '%s')\n"
                                   "  sink:      GStreamer sink "
                                   "(default: '%s')\n"),
                                 argv[0],
-                                lastfm_audio_default_convert_name(),
                                 lastfm_audio_default_decoder_name(),
-                                lastfm_audio_default_mixer_name(),
                                 lastfm_audio_default_sink_name());
                         return -1;
                 }
